package Data::Unixish::CmdLine;

use 5.010;
use strict;
use warnings;

our $VERSION = '1.26'; # VERSION

1;
# ABSTRACT: Run a dux function from the command-line


__END__
=pod

=head1 NAME

Data::Unixish::CmdLine - Run a dux function from the command-line

=head1 VERSION

version 1.26

=head1 SYNOPSIS

 # for now, use dux script

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 DESCRIPTION


This module has L<Rinci> metadata.

=head1 FUNCTIONS


None are exported by default, but they are exportable.

=cut

